@@ -1,20 +1,9 @@
-/* This file is part of the KDE Project
-   Copyright (c) 2009-2011 Sebastian Trueg <trueg@kde.org>
-   Copyright (c) 2013-2014 Vishesh Handa <vhanda@kde.org>
+/*
+    This file is part of the KDE Project
+    SPDX-FileCopyrightText: 2009-2011 Sebastian Trueg <trueg@kde.org>
+    SPDX-FileCopyrightText: 2013-2014 Vishesh Handa <vhanda@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License version 2 as published by the Free Software Foundation.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef BALOO_METADATA_MOVER_H_
@@ -33,8 +22,8 @@ class MetadataMover : public QObject
     Q_OBJECT
 
 public:
-    MetadataMover(Database* db, QObject* parent = nullptr);
-    ~MetadataMover();
+    explicit MetadataMover(Database* db, QObject* parent = nullptr);
+    ~MetadataMover() override;
 
 public Q_SLOTS:
     void moveFileMetadata(const QString& from, const QString& to);
