@@ -1,22 +1,9 @@
 /*
- * This file is part of the KDE Baloo Project
- * Copyright (C) 2014  Vishesh Handa <me@vhanda.in>
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
- *
- */
+    This file is part of the KDE Baloo Project
+    SPDX-FileCopyrightText: 2014 Vishesh Handa <me@vhanda.in>
+
+    SPDX-License-Identifier: LGPL-2.1-or-later
+*/
 
 #ifndef BALOO_PENDINGFILE_H
 #define BALOO_PENDINGFILE_H
@@ -32,10 +19,9 @@ namespace Baloo {
 class PendingFile
 {
 public:
-    explicit PendingFile(const QString& path = QString());
+    explicit PendingFile(const QString& path);
 
     QString path() const;
-    void setPath(const QString& path);
 
     void setAttributeChanged() { m_attributesChanged = true; }
     void setClosedOnWrite() { m_closedOnWrite = true; }
@@ -43,6 +29,7 @@ public:
     void setCreated() { m_created = true; }
     void setDeleted() { m_deleted = true; }
 
+    bool isNewFile() const;
     bool shouldIndexContents() const;
     bool shouldIndexXAttrOnly() const;
     bool shouldRemoveIndex() const;
@@ -71,7 +58,6 @@ private:
 
 }
 
-Q_DECLARE_METATYPE(Baloo::PendingFile);
-Q_DECLARE_TYPEINFO(Baloo::PendingFile, Q_MOVABLE_TYPE);
+Q_DECLARE_TYPEINFO(Baloo::PendingFile, Q_RELOCATABLE_TYPE);
 
 #endif // BALOO_PENDINGFILE_H
